/*
 * ----------------------------------------------------------------------------
 *
 * zfconn.h -- zzzforward ZFConn connection data type
 * Copyright (C) 2004 Fabian "zzznowman" Pietsch
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * ----------------------------------------------------------------------------
 *
 */

#ifndef __ZFCONN_H
#define __ZFCONN_H

/* wrapper around struct sockaddr_in */
typedef struct sockaddr_in SysSA;

/* ZFConn status */
typedef enum {
	ZFCS_NULL       = 0x00,  /* no status bits set        */
	ZFCS_CCONNECTED = 0x01,  /* client connected          */
	ZFCS_SCONNECTED = 0x02,  /* server connected          */
	ZFCS_CONNECTED  = ZFCS_CCONNECTED | ZFCS_SCONNECTED
	                         /* ZFConn is fully connected */
} ZFConnStat;

/* structure holding connection information (linked list) */
typedef struct __ZFConn {
	int              id;         /* unique connection id                 */
	ZFConnStat       status;     /* connection status                    */
	int              client_s;   /* client which connected to us         */
	SysSA            client_a;   /* client's address                     */
	int              server_s;   /* server to which we connected in turn */
	SysSA            server_a;   /* server's address                     */
	struct __ZFConn *next;       /* pointer to next element in list      */
} ZFConn;


/* linked list to store every ZFConn */
extern ZFConn *connections;


/*
 * connection-related helper functions
 */

/* zf_connect() -- connect to desthost:destport */
extern int zf_connect(int *s, SysSA *sa);

/* zf_listen() -- perform steps necessary for accepting incoming connections */
extern int zf_listen(int *s, int port);

/* zf_select() -- sleep until some socket state changes */
extern int zf_select(int listens);


/*
 * data structure handling functions
 */

/* zfc_new() -- create new ZFConn from listening socket */
extern ZFConn *zfc_new(int listens);

/* zfc_free() -- free a ZFConn */
extern void zfc_free(ZFConn *conn);

/* zfc_disconnect() -- disconnect a ZFConn */
extern int zfc_disconnect(ZFConn *conn);

/* zfc_forward() -- forward data between ZFConn's client & server */
extern int zfc_forward(ZFConn *conn);

/* zfc_parent() -- find ZFConn's parent */
extern ZFConn *zfc_parent(ZFConn *conn);

#endif  /* __ZFCONN_H */
