/*
 * ----------------------------------------------------------------------------
 *
 * zzzforward.h -- listen on a socket and forward incoming connections
 * Copyright (C) 2003, 2004 Fabian "zzznowman" Pietsch
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * ----------------------------------------------------------------------------
 *
 */

#ifndef __ZZZFORWARD_H
#define __ZZZFORWARD_H

/*
 * compile-time configurable defaults
 */

/* default port to listen on */
#define ZF_LISTENPORT 7000

/* retries on send queue full */
#define TRIES_MAX 10    /* maximum number of retries when send queue is full */
#define TRIES_DELAY 50  /* delay between retries (ms)                        */


/*
 * misc macro definitions
 */

/* stringification macros needed for VERSION */
#define Str(x) #x
#define Xstr(x) Str(x)

/* zzzforward version data (taken from zzzutils) */
#define VER_MAJOR 0
#define VER_MINOR 1
#define VER_REVISION 3

#define VERSION Xstr(VER_MAJOR) "." Xstr(VER_MINOR) "." Xstr(VER_REVISION)
#define PRODUCT_NAME "zzzforward"
#define PRODUCT_VERSION PRODUCT_NAME " " VERSION


/*
 * global variables
 */

/* destination to use as "server" */
extern char *desthost;
extern char *destport;

/* port zzzforward will be listening on */
extern int listenport;
extern int listens;


/*
 * global functions
 */

/* zf_forward() -- forward pending data between all active connections */
extern int zf_forward(void);

/* zf_sleep() -- sleep and perform necessary actions after awaking */
extern int zf_sleep(void);

/* zf_usage() -- print usage information, then exit program */
extern void zf_usage(FILE *stream, int exit_status);

/* zf_version() -- print out version information, then exit program */
extern void zf_version(void);

#endif  /* __ZZZFORWARD_H */
